@@ -23,7 +23,7 @@ def list_tables(ctx):
         )
     except Exception as e:
         click.secho(
-            f"Unable to list tables from url [{get_config(ctx, 'data_connect.url')}]: {e}",
+            f"Unable to list tables: {e}",
             fg="red",
         )
         sys.exit(1)
