@@ -17,7 +17,7 @@ def login_with_personal_access_token(
         session = requests.Session()
         # login at /login/token
         login_res = session.get(
-            f'{auth_params["url"]}/login/token',
+            auth_params["url"] + "login/token",
             params={"token": personal_access_token, "email": email},
             allow_redirects=False,
         )
@@ -29,7 +29,7 @@ def login_with_personal_access_token(
             )
 
         auth_code_res = session.get(
-            f'{auth_params["url"]}/oauth/authorize',
+            auth_params["url"] + "oauth/authorize",
             params={
                 "response_type": "code",
                 "scope": auth_scopes,
@@ -53,7 +53,7 @@ def login_with_personal_access_token(
             raise Exception("The authorization failed")
 
         auth_token_res = session.post(
-            f'{auth_params["url"]}/oauth/token',
+            auth_params["url"] + "oauth/token",
             data={
                 "grant_type": "authorization_code",
                 "code": auth_code,
@@ -79,7 +79,7 @@ def login_device_code(audience=None, auth_params=default_auth, open_browser=True
         session = requests.Session()
 
         device_code_res = session.post(
-            f'{auth_params["url"]}/oauth/device/code',
+            auth_params["url"] + "oauth/device/code",
             params={
                 "grant_type": "urn:ietf:params:oauth:grant-type:device_code",
                 "client_id": auth_params["client"]["id"],
@@ -107,7 +107,7 @@ def login_device_code(audience=None, auth_params=default_auth, open_browser=True
 
         while time() < expiry:
             auth_token_res = session.post(
-                f'{auth_params["url"]}/oauth/token',
+                auth_params["url"] + "oauth/token",
                 data={
                     "grant_type": "urn:ietf:params:oauth:grant-type:device_code",
                     "device_code": device_code,
@@ -132,7 +132,7 @@ def login_device_code(audience=None, auth_params=default_auth, open_browser=True
 
 def login_refresh_token(token=None, auth_params=default_auth):
     refresh_token_res = requests.post(
-        f'{auth_params["url"]}/oauth/token',
+        auth_params["url"] + "oauth/token",
         data={
             "grant_type": "refresh_token",
             "refresh_token": token["refresh_token"],
