@@ -8,12 +8,12 @@ def list_collections(collections_url):
 
 
 def list_tables(collections_url, collection_name):
-    collection_tables_url = f"{collections_url}/{collection_name}/data-connect/tables"
+    collection_tables_url = collections_url + f"{collection_name}/data-connect/tables"
     return req.get(collection_tables_url).json()
 
 
 def query(collections_url, collection_name, query, format="json"):
-    collection_query_url = f"{collections_url}/{collection_name}/data-connect/search"
+    collection_query_url = collections_url + f"{collection_name}/data-connect/search"
 
     res = req.post(collection_query_url, json={"query": query})
 
@@ -23,7 +23,7 @@ def query(collections_url, collection_name, query, format="json"):
         if "errors" in results:
             error_msg = results["errors"][0]["title"]
             raise Exception(error_msg)
-        raise Exception()
+        raise Exception(f"Error reaching [{collections_url}]")
 
     if format == "csv":
         return format_query_result_as_csv(results["data"])
