@@ -16,7 +16,7 @@ TEST_DATA_CONNECT_FILES_TABLE = (
 
 # COLLECTIONS
 TEST_COLLECTIONS_URI = (
-    os.getenv("E2E_COLLECTIONS_URI") or "https://explorer.dnastack.com/api/collections"
+    os.getenv("E2E_COLLECTIONS_URI") or "https://explorer.dnastack.com/api/collections/"
 )
 TEST_COLLECTION_NAME = (
     os.getenv("E2E_COLLECTION_NAME") or "sars-cov-2-ncbi-sequence-read-archive"
@@ -63,7 +63,7 @@ TEST_WES_URI = os.getenv("E2E_WES_URI") or "https://workspaces-wes.beta.dnastack
 # AUTH
 TEST_AUTH_PARAMS = {
     "publisher": {
-        "url": "https://wallet.publisher.dnastack.com",
+        "url": "https://wallet.publisher.dnastack.com/",
         "client": {
             "redirect_url": "https://wallet.publisher.dnastack.com/",
             "id": "publisher-cli",
@@ -71,7 +71,7 @@ TEST_AUTH_PARAMS = {
         },
     },
     "prod": {
-        "url": "https://wallet.prod.dnastack.com",
+        "url": "https://wallet.prod.dnastack.com/",
         "client:": {
             "redirect_url": "https://wallet.prod.dnastack.com/",
             "id": "publisher-cli",
@@ -79,7 +79,7 @@ TEST_AUTH_PARAMS = {
         },
     },
     "wes": {
-        "url": os.getenv("E2E_WES_WALLET_URI") or "https://wallet.prod.dnastack.com",
+        "url": os.getenv("E2E_WES_WALLET_URI") or "https://wallet.prod.dnastack.com/",
         "client": {
             "id": os.getenv("E2E_WES_WALLET_CLIENT") or "wes-cli-test-client-id",
             "secret": os.getenv("E2E_WES_WALLET_CLIENT_SECRET")
