@@ -40,9 +40,12 @@ class TestCliFilesCommand(unittest.TestCase):
         )
 
         # clean up ./out directory
-        pathlib.Path(f"{os.getcwd()}/out/{TEST_DRS[TEST_DRS_WITH_ACCESS_URL]}").unlink(
-            missing_ok=True
-        )
+        if pathlib.Path(
+            f"{os.getcwd()}/out/{TEST_DRS[TEST_DRS_WITH_ACCESS_URL]}"
+        ).exists():
+            pathlib.Path(
+                f"{os.getcwd()}/out/{TEST_DRS[TEST_DRS_WITH_ACCESS_URL]}"
+            ).unlink()
         pathlib.Path(f"{os.getcwd()}/out").rmdir()
 
     @unittest.skip(
@@ -72,9 +75,12 @@ class TestCliFilesCommand(unittest.TestCase):
             ).exists()
         )
         # clean up ./out directory
-        pathlib.Path(f"{os.getcwd()}/out/{TEST_DRS[TEST_DRS_WITH_ACCESS_ID]}").unlink(
-            missing_ok=True
-        )
+        if pathlib.Path(
+            f"{os.getcwd()}/out/{TEST_DRS[TEST_DRS_WITH_ACCESS_ID]}"
+        ).exists():
+            pathlib.Path(
+                f"{os.getcwd()}/out/{TEST_DRS[TEST_DRS_WITH_ACCESS_ID]}"
+            ).unlink()
         pathlib.Path(f"{os.getcwd()}/out").rmdir()
 
     def test_multiple_drs_download(self):
@@ -100,7 +106,8 @@ class TestCliFilesCommand(unittest.TestCase):
 
         # clean up ./out directory
         for drs_file in TEST_DRS.values():
-            pathlib.Path(f"{os.getcwd()}/out/{drs_file}").unlink(missing_ok=True)
+            if pathlib.Path(f"{os.getcwd()}/out/{drs_file}").exists():
+                pathlib.Path(f"{os.getcwd()}/out/{drs_file}").unlink()
 
         pathlib.Path(f"{os.getcwd()}/out").rmdir()
 
@@ -132,9 +139,11 @@ class TestCliFilesCommand(unittest.TestCase):
             self.assertTrue(pathlib.Path(f"{os.getcwd()}/out/{drs_file}").exists())
 
         # clean up ./out directory
-        pathlib.Path(f"{os.getcwd()}/download_input_file.txt").unlink(missing_ok=True)
+        if pathlib.Path(f"{os.getcwd()}/download_input_file.txt").exists():
+            pathlib.Path(f"{os.getcwd()}/download_input_file.txt").unlink()
         for drs_file in TEST_DRS.values():
-            pathlib.Path(f"{os.getcwd()}/out/{drs_file}").unlink(missing_ok=True)
+            if pathlib.Path(f"{os.getcwd()}/out/{drs_file}").exists():
+                pathlib.Path(f"{os.getcwd()}/out/{drs_file}").unlink()
         pathlib.Path(f"{os.getcwd()}/out").rmdir()
 
     def test_drs_download_from_broken_url(self):
